<template>
  <a-modal
    :title="title"
    :width="1350"
    :visible="visible"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              label="保养标准"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请选择保养标准'"
                v-decorator="['maintenanceStandardNum', {} ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              label="设备名称"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入设备名称'"
                v-decorator="['equipmentName', {} ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              label="保养周期"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-select
                :placeholder="disableSubmit?'':'请选择保养周期'"
                :options="this.maintenanceCycles"
                style="width: 100%"
                :disabled="true"
                v-decorator="['maintenanceCycleId', {}]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              label="保养日期"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <j-date
                :disabled="true"
                v-decorator="['maintenanceTime', {} ]"
                placeholder="请选择保养时间"
                style="width: 100%"
                :showTime="true"
                dateFormat="YYYY-MM-DD HH:mm:ss"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24 / 2">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="派工方式"
            >
              <j-dict-select-tag
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请选择派工方式'"
                :triggerChange="true"
                dictCode="assign_mode"
                v-decorator="['assignMode', validatorRules.assignMode]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="24 / 2">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="责任班组"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入责任班组'"
                v-decorator="['teamName', validatorRules.teamName ]"
              />
            </a-form-item>
          </a-col>
        </a-row>

        <a-row :gutter="24">
          <a-col :span="12">
            <a-form-item
              label="责任人"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input-search
                :disabled="disableSubmit"
                placeholder="责任人"
                enter-button
                @search="onDutyUserList()"
                :read-only="true"
                v-decorator="['maintenanceUserName', validatorRules.maintenanceUserName]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row
          hidden
          :gutter="24"
        >
          <a-col :span="12">
            <a-form-item
              label="责任班组"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入责任班组'"
                v-decorator="['teamId', validatorRules.teamId ]"
              />
            </a-form-item>
          </a-col>
          <a-col :span="12">
            <a-form-item
              label="责任人/点检人"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
            >
              <a-input
                allow-clear
                :disabled="true"
                :placeholder="disableSubmit?'':'请输入责任人/点检人'"
                v-decorator="['maintenanceUserId', validatorRules.maintenanceUserId ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <!-- <a-table
          ref="table"
          size="middle"
          bordered
          rowKey="id"
          :columns="columns"
          :dataSource="dataSource"
          :pagination="ipagination"
          :loading="loading"
          @change="handleTableChange"
        >
          <template
            v-for="col in columns"
            :slot="col.dataIndex"
            slot-scope='text, record, index'
          >
            <div :key="col.dataIndex">
              <a-input-search
                v-if="col.dataIndex == 'assignUser'"
                enter-button
                @search="onSearchUser(index)"
                :value="text"
                :read-only="true"
                @change="(e) => handleChange(e, record.key, col, index)"
              />
            </div>
          </template>
        </a-table> -->
      </a-form>
    </a-spin>
    <user-list
      ref="UserList"
      @sendDutyUserRecord='sendDutyUserRecord'
    ></user-list>
  </a-modal>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import Tooltip from 'ant-design-vue/es/tooltip'
import { getAction, postAction, requestPut, httpAction, deleteAction } from '@/api/manage'
import pick from 'lodash.pick'
import JMultiSelectTag from '@/components/dict/JMultiSelectTag'
import UserSelectList4Assign from './UserSelectList4Assign'
import JEllipsis from '@/components/jeecg/JEllipsis'//引入过长裁剪
import UserList from '.././dailyInspectionOrder/UserList'

export default {
  name: "MaintenanceOrderAssignModal",
  mixins: [JeecgListMixin],
  components: {
    JMultiSelectTag,
    Tooltip,
    JDictSelectTag,
    UserSelectList4Assign,
    JEllipsis,
    UserList
  },
  data() {
    return {
      title: "",
      result: true,
      visible: false,
      disableSubmit: false,
      submitBtn: false,
      model: {},
      confirm: true,
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      confirmLoading: false,
      maintenanceCycles:[],
      form: this.$form.createForm(this),
      dateFormat: 'YYYY-MM-DD',
      selectedRowKeys: [],//选中的rowid
      rowKey: "",//table中选中的行id
      dataSource: [],
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 10,
        pageSizeOptions: ['5', '10', '30', '50', '100'],
        showTotal: (total, range) => {
          return range[0] + "-" + range[1] + " 共" + total + "条"
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      // columns: [
      //   {
      //     title: '#',
      //     dataIndex: '',
      //     key: 'rowIndex',
      //     align: 'center',
      //     customRender: function (t, r, index) {
      //       return parseInt(index) + 1
      //     }
      //   },
      //   {
      //     title: '保养工单号',
      //     align: 'center',
      //     dataIndex: 'num',
      //   },
      //   {
      //     title: '使用部门',
      //     align: 'center',
      //     dataIndex: 'departName',
      //   },
      //   {
      //     title: '责任部门',
      //     align: 'center',
      //     dataIndex: 'dutyDepartName',
      //   },
      //   {
      //     title: '保养标准编码',
      //     align: 'center',
      //     dataIndex: 'maintenanceStandardNum',
      //   },
      //   {
      //     title: '保养周期',
      //     align: 'center',
      //     dataIndex: 'maintenanceCycleName',
      //   },
      //   {
      //     title: '员工id',
      //     align: 'center',
      //     dataIndex: 'recipientUserId',
      //     className: "notShow",
      //   },
      //   {
      //     title: '*指派人员',
      //     align: 'center',
      //     dataIndex: 'assignUser',
      //     className: 'red',
      //     scopedSlots: { customRender: 'assignUser' },
      //   },
      // ],
      validatorRules: {
        maintenanceUserName:{
          rules: [
            { required: true, message: '请选择责任人!' },
          ]
        }
      },
      url: {
        // orderAssign: "/eam/specialtyInspectionOrder/orderAssign",
        add: "/eam/dailyMaintenanceOrder/add",
        assign: "/eam/dailyMaintenanceOrder/assign",
      },
    }
  },
  mounted() {
    this.$bus.$on('selectionRows', (data) => {
      this.dataSource = []
      //getCurrSelected 事件 接收组件传递的参数
      for (let i = 0; i < data.length; i++) {
        this.dataSource.push({
          id: data[i].id,
          num: data[i].num,
          departName: data[i].departName,
          dutyDepartName: data[i].dutyDepartName,
          maintenanceStandardNum: data[i].maintenanceStandardNum,
          maintenanceCycleName: data[i].maintenanceCycleName,
        })
      }
    })
  },

  methods: {

    handleShow() {
      this.visible = true;
    },

    edit(record) {
      let that = this;
      this.maintenanceCycles = record.maintenanceCycles
      this.equipmentId = record.equipmentId
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      if (record.dailyMaintenanceDetails != undefined) {
        const temp = [...record.dailyMaintenanceDetails];
        that.dataSource = temp;
      }
      that.$nextTick(() => {
        that.form.setFieldsValue(pick(that.model, 'num',
          'equipmentName', 'maintenanceCycleId', 'maintenanceStandardNum',
          'maintenanceTime', 'effectiveTime', 'unit', 'teamId',
          'assignMode', 'teamName', 'maintenanceUserId', 'maintenanceUserName', 'remark'));
      });
    },

    onDutyUserList() {
      let data = this.form.getFieldsValue(['teamId']);
      if (data.teamId == null || data.teamId == "") {
        this.$message.warning("请先维护班组！");
        return
      }
      this.$refs.UserList.list(data.teamId);
      this.$refs.UserList.title = "选择人员";
    },
    sendDutyUserRecord(data) {
      let record = data.record;
      this.form.setFieldsValue({ maintenanceUserId: record.id, maintenanceUserName: record.username + "/" + record.realname });
    },

    handleOk() {
      const that = this;
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.assign, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },

    close() {
      this.$emit('close')
      this.visible = false
    },

    handleCancel() {
      this.close();
    },

    // handleOk() {
    //   const that = this
    //   this.form.validateFields((err, values) => {
    //     if (!err) {
    //       that.confirmLoading = true
    //       let formData = Object.assign(this.model, values)
    //       for (let i = 0; i < this.dataSource.length; i++) {
    //         let o = this.dataSource[i]
    //         if (o.recipientUserId == null || o.recipientUserId == '') {
    //           that.$message.warning('请指派人员！')
    //           that.confirmLoading = false;
    //           return
    //         }

    //       }
    //       formData.specialtyInspectionOrderList = this.dataSource
    //       requestPut(that.url.orderAssign, formData, { id: that.model.id }).then((res) => {
    //         if (res.success) {
    //           that.$message.success(res.message)
    //           that.$emit('ok')
    //           that.alterFlag = new Date()
    //         } else {
    //           that.$message.warning(res.message)
    //         }
    //       }).finally(() => {
    //         that.confirmLoading = false
    //         that.close()
    //       })
    //     }
    //     // else {
    //     //   this.isDisabled = false
    //     // }
    //   })
    // },

    // handleChangeRadio(value, key, column, index) {
    //   const temp = [...this.dataSource]
    //   const target = temp.filter((item) => key === item.key)[index]
    //   if (target) {
    //     target['productType'] = value.target.value
    //   }
    //   this.dataSource = temp
    // },

    // handleChange(value, key, column, index) {
    //   const temp = [...this.dataSource]
    //   const target = temp.filter((item) => key === item.key)[index]
    //   if (target) {
    //     target[column.dataIndex] = value
    //     this.dataSource = temp
    //   }
    // },

    // sendUserRecord(data, val) {
    //   let record = data.record
    //   const temp = [...this.dataSource]
    //   const target = temp[this.recordIndex]
    //   if (target) {
    //     target.assignUser = record.realname
    //     target.recipientUserId = record.id
    //     this.dataSource = temp
    //   }
    // },

    // onSearchUser(index) {
    //   this.recordIndex = index
    //   this.$refs.UserSelectList4Assign.list()
    //   this.$refs.UserSelectList4Assign.title = '人员选择'
    // },

    loadData() { },

  },
}
</script>

<style scoped>
/deep/ .red {
  color: red;
}
/deep/ .notShow {
  display: none;
}
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
.ant-table-tbody .ant-table-row td {
  padding-top: 10px;
  padding-bottom: 10px;
}

.anty-row-operator button {
  margin: 0 5px;
}

.ant-btn-danger {
  background-color: #ffffff;
}

.ant-modal-cust-warp {
  height: 100%;
}

.ant-modal-cust-warp .ant-modal-body {
  height: calc(100% - 110px) !important;
  overflow-y: auto;
}

.ant-modal-cust-warp .ant-modal-content {
  height: 90% !important;
  overflow-y: hidden;
}

.frozenRowClass {
  color: #c9c9c9;
}
.hight {
  color: #f5222d;
}
.middle {
  color: #fa8c16;
}
.low {
  color: #52c41a;
}
.dataUnKnow {
  color: #1890ff;
}
</style>